==> DeepCell-0.12.0rc0.tar.gz: DeepCell-0.12.0rc0/deepcell/utils/tracking_utils.py <==
# Copyright 2016-2022 David Van Valen at California Institute of Technology
# (Caltech), with support from the Paul Allen Family Foundation, Google,
# & National Institutes of Health (NIH) under Grant U24CA224309-01.
# All rights reserved.
#
# Licensed under a modified Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.github.com/vanvalenlab/deepcell-tf/LICENSE
#
# The Work provided may be used for non-commercial academic purposes only.
# For any other use of the Work, including commercial use, please contact:
# vanvalenlab@gmail.com
#
# Neither the name of Caltech nor the names of its contributors may be used
# to endorse or promote products derived from this software without specific
# prior written permission.
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
"""Utilities for tracking cells"""

from __future__ import absolute_import
from __future__ import print_function
from __future__ import division

# pylint: disable=unused-import
from deepcell_tracking.utils import clean_up_annotations
from deepcell_tracking.utils import resize
from deepcell_tracking.utils import count_pairs
from deepcell_tracking.utils import load_trks
from deepcell_tracking.utils import trk_folder_to_trks
from deepcell_tracking.utils import save_trks
from deepcell_tracking.utils import trks_stats
# pylint: enable=unused-import

del absolute_import
del print_function
del division

==> DeepCell-0.12.2.tar.gz: DeepCell-0.12.2/deepcell/utils/tracking_utils.py <==
# Copyright 2016-2022 David Van Valen at California Institute of Technology
# (Caltech), with support from the Paul Allen Family Foundation, Google,
# & National Institutes of Health (NIH) under Grant U24CA224309-01.
# All rights reserved.
#
# Licensed under a modified Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.github.com/vanvalenlab/deepcell-tf/LICENSE
#
# The Work provided may be used for non-commercial academic purposes only.
# For any other use of the Work, including commercial use, please contact:
# vanvalenlab@gmail.com
#
# Neither the name of Caltech nor the names of its contributors may be used
# to endorse or promote products derived from this software without specific
# prior written permission.
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
"""Utilities for tracking cells"""

from __future__ import absolute_import
from __future__ import print_function
from __future__ import division

# pylint: disable=unused-import
from deepcell_tracking.utils import clean_up_annotations
from deepcell_tracking.utils import resize
from deepcell_tracking.utils import count_pairs
from deepcell_tracking.trk_io import load_trks
from deepcell_tracking.trk_io import trk_folder_to_trks
from deepcell_tracking.trk_io import save_trks
from deepcell_tracking.utils import trks_stats
# pylint: enable=unused-import

del absolute_import
del print_function
del division
